'
' XGA_DISP - initial DISP (display) generator cog for XGA driver, runs on two cogs to generate even/odd lines v0.80
'
' Copyright 2009 William Henning
'
' http://Mikronauts.com
'
' mikronauts@gmail.com
'
' LICENSE
'
' XGA_DISP is licensed for distribution in one of two ways:
'
' GPL v2.0 - which means that you must also distribute the source code to your application under the GPL
'
' Here is a link to the terms of the GPL v2.0: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
'
' -or-
'
' If you don't want to distribute your source code you can contact me for a commercial license - this means
' that you will have to pay a reasonable licensing fee if you do not wish to freely release your source code.
'
' I will gladly accept improvements to the drivers, however I ask that I can dual license the improved drivers
' as detailed above, and of course I will give you credit in the source and documentation for any of your
' improvements that I use.
'
' Please Note: You may not remove or modify these terms from any of the files or documentation.
'
' CREDITS:
'
' Chip Gracey for the Propeller and multi-cog video synchronization example code
'
' ariba, jazzed, PhiPi and lonesock from the forums for a great fast way of building longs from 8 bit inputs
' see the original thread at http://forums.parallax.com/forums/default.aspx?f=25&p=1&m=349679
'
' Hanno for making ViewPort that helped me debug Morpheus
'
'

CON

' 1024x768 settings - signals as 1024 x 768 @ 67Hz

'  hp = 1024     'horizontal pixels
'  hf = 24       'horizontal front porch pixels
'  hs = 136      'horizontal sync pixels
'  hb = 160      'horizontal back porch pixels

'  vp = 768      'vertical pixels
'  vf = 3        'vertical front porch lines
'  vs = 6        'vertical sync lines
'  vb = 9'29       'vertical back porch lines

  pr = 55   '55 best?    'pixel rate in MHz at 80MHz system clock (5MHz granularity)


{

1024x768 @ 60Hz

1024 active pixels = 1260    = 15.75us
  24 hfp           =  29.53  =   .40us
 136 hsync         = 167.38  =  2.10us
 160 hbp           = 197     =  2.46us
                               -------
                               20.71us
----
1344 pix

 768 active lines
   3 vfp
   6 vsync
  29 vbp
----
 806 lines

806 lines x 1344 pix x 60Hz = 64995840 dots per sec, ie 65MHz

1344 pix / 65M = 20.6769us whole line, * 80 = 1092 ticks
               = 15.7538us active pixel time = 
               = 15.3846ns/pixel
               = 246.1538ns/16pix

}

var
  long cog, vargs[4]

PUB start(SyncPtr,buff,lin, color)

  vargs[0] := SyncPtr
  vargs[1] := SyncPtr + 208*1024
  vargs[2] := buff
  vargs[3] := lin
  colbase  := color

  cog := cognew(@xgacog,@vargs)

DAT

' 1024x768x4 color driver, sync engine

                        org                             'set origin to $000 for start of program

' Initialization code - init I/O
                                                                                              

xgacog          jmp     #init          

line            long    0[64]

init            mov     argptr,par

                rdlong  startdelay,argptr
                add     argptr,#4

                rdlong  vcodelay,argptr
                add     argptr,#4

                rdlong  buffer,argptr
                add     argptr,#4

                rdlong  oddeven,argptr wz


                or      oddeven,#0 wz
         if_nz  add     buffer,#256             ' adjust buffer ptr

                mov     outa,#0

odd_lines       mov     dira,whitevid    ' set for output
                movi    frqa,#(pr / 5) << 3     'set pixel rate
'                movi    frqa,#12 << 3     'set pixel rate - note the hidden 5MHz xtal dependancy! Will fix
                mov     vcfg,vid_vcfg           'set video configuration
                mov     vscl,#1

                mov   colptr,colbase

                waitcnt startdelay,#0
                movi    ctra,#%00001_101        'enable PLL in ctra (VCO runs at 4x)
                waitcnt vcodelay,#0
                mov     vscl,#100
                mov     phsa, #0
                waitvid zero,zero
       
vnext_frame     mov     count_active,   active_lines
                mov     count_vbp,      vbp_lines
                mov     count_vsync,    vsync_lines
                mov     count_vfp,      vfp_lines
                
'--------------------------------------------------------------------
' Active video - the visible scan lines :)
'--------------------------------------------------------------------

        mov   colptr,colbase

vactivevid      mov     t,oddeven
                xor     t,count_active
                rdlong rgb,colptr
                add   colptr,#4
                and     t,#1 wz
          if_nz jmp     #do_disp
          
do_read         mov     vscl,act_vscl
                nop
                waitvid zero,#0
                call    #readline
                jmp     #go_on

do_disp         mov     vscl,reg_vscl
                mov     t,#64
vlp             waitvid rgb,1                  ' 4 color
                add     vlp,#1                 ' 4 color
'vlp             waitvid 1,truecolor             ' 256 color
'                add     vlp,dest_inc            ' 256 color
                djnz    t,#vlp
'                mov     vlp,blank              ' 4 color \ either
                movs    vlp,#1                 ' 4 color / or
'                movd    vlp,#1                  ' 256 color

go_on           mov     vscl,fp_vscl
                waitvid zero, #0

                mov     vscl,hs_vscl
                waitvid zero, #0

                mov     vscl, bp_vscl
                waitvid zero, #0
                djnz    count_active, #vactivevid

'--------------------------------------------------------------------

vvert_fp        mov     vscl,act_vscl
                waitvid zero, #0
                mov     vscl,fp_vscl
                waitvid zero, #0
                mov     vscl,hs_vscl
                waitvid zero, #0
                mov     vscl, bp_vscl
                waitvid zero, #0
                djnz    count_vbp, #vvert_fp
                
vvert_sync      mov     vscl,reg_vscl
                mov     t,#64
vsl2            waitvid zero, #0
                djnz    t,#vsl2
                
                mov     vscl,fp_vscl
                waitvid zero, #0
                mov     vscl,hs_vscl
                waitvid zero, #0
                mov     vscl, bp_vscl
                waitvid zero, #0
                djnz    count_vsync, #vvert_sync
                
vvert_bp        mov     vscl,act_vscl
                waitvid zero, #0
                mov     vscl,fp_vscl
                waitvid zero, #0
                mov     vscl,hs_vscl
                waitvid zero, #0
                mov     vscl, bp_vscl
                waitvid zero, #0
                djnz    count_vfp, #vvert_bp

                mov   colptr,colbase
                jmp     #vnext_frame
                
' ***********************************************************************

blank           waitvid rgb,1

rot             long $102030ff
dest_inc        long 512

zero            long 0
argptr          long 0
startdelay      long 0
vcodelay        long 0

buffer          long 0
oddeven         long 0

highsync        long $03030303 ' pin24&25, low bits, are vs & hs respectively

sync_vcfg       long    %0_01_1_0_0_000_00000100000_011_0_00000011 ' P24,P25 Vsync, Hsync
vid_vcfg        long    %0_01_1_0_0_000_00000100000_010_0_11111111 ' P16-P23 RRRGGGBB data

reg_vscl        long    $00001000+16            '%0000_0000_0000_0000_0001_000000010000

act_vscl        long    $1000+1024'$00001000+1024          '%000000000000_00000001_010000000000
fp_vscl         long    $1000+24  '$00001000+24            '%000000000000_00000001_000000011000
hs_vscl         long    $1000+136 '$00001000+96           '%000000000000_00000001_000010001000    
bp_vscl         long    $1000+160 '$00001000+96           '%000000000000_00000001_000101000000

vs_vscl         long    1344 '$00001000+1344          '%000000000000_00000001_010101000000

hsvalue         long    %11111101_11111101_11111101_11111101
vs_value        long    %11111110_11111110_11111110_11111110
hsvs_value      long    %11111100_11111100_11111100_11111100

active_lines    long    768
vbp_lines       long    3
vsync_lines     long    6
vfp_lines       long    29    
horiz_longs     long    64

colbase         long    0
colptr          long    0

count_active    long    0
count_vbp       long    0
count_vsync     long    0
count_vfp       long    0

vidpins         long    $00FF0000

hs_pin          long    $02000000

syncpins        long    $03000000
blackvid        long    $00000000
whitevid        long    $00FF0000
rgb             long    $E01C0300
allones         long    $ffffffff
'truecolor       long    %00000000_01010101_10101010_11111111
truecolor       long    %%3333_2222_1111_0000
t               long    0  ' if left blank, picks up following junk or random


readline        mov     t,buffer

                rdlong  1,t
                add     t,#4
                rdlong  2,t
                add     t,#4
                rdlong  3,t
                add     t,#4
                rdlong  4,t
                add     t,#4
                rdlong  5,t
                add     t,#4
                rdlong  6,t
                add     t,#4
                rdlong  7,t
                add     t,#4
                rdlong  8,t
                add     t,#4

                rdlong  9,t
                add     t,#4
                rdlong  10,t
                add     t,#4
                rdlong  11,t
                add     t,#4
                rdlong  12,t
                add     t,#4
                rdlong  13,t
                add     t,#4
                rdlong  14,t
                add     t,#4
                rdlong  15,t
                add     t,#4
                rdlong  16,t
                add     t,#4

                rdlong  17,t
                add     t,#4
                rdlong  18,t
                add     t,#4
                rdlong  19,t
                add     t,#4
                rdlong  20,t
                add     t,#4
                rdlong  21,t
                add     t,#4
                rdlong  22,t
                add     t,#4
                rdlong  23,t
                add     t,#4
                rdlong  24,t
                add     t,#4

                rdlong  25,t
                add     t,#4
                rdlong  26,t
                add     t,#4
                rdlong  27,t
                add     t,#4
                rdlong  28,t
                add     t,#4
                rdlong  29,t
                add     t,#4
                rdlong  30,t
                add     t,#4
                rdlong  31,t
                add     t,#4
                rdlong  32,t
                add     t,#4

                rdlong  33,t
                add     t,#4
                rdlong  34,t
                add     t,#4
                rdlong  35,t
                add     t,#4
                rdlong  36,t
                add     t,#4
                rdlong  37,t
                add     t,#4
                rdlong  38,t
                add     t,#4
                rdlong  39,t
                add     t,#4
                rdlong  40,t
                add     t,#4
                
                rdlong  41,t
                add     t,#4
                rdlong  42,t
                add     t,#4
                rdlong  43,t
                add     t,#4
                rdlong  44,t
                add     t,#4
                rdlong  45,t
                add     t,#4
                rdlong  46,t
                add     t,#4
                rdlong  47,t
                add     t,#4
                rdlong  48,t
                add     t,#4

                rdlong  49,t
                add     t,#4
                rdlong  50,t
                add     t,#4
                rdlong  51,t
                add     t,#4
                rdlong  52,t
                add     t,#4
                rdlong  53,t
                add     t,#4
                rdlong  54,t
                add     t,#4
                rdlong  55,t
                add     t,#4
                rdlong  56,t
                add     t,#4

                rdlong  57,t
                add     t,#4
                rdlong  58,t
                add     t,#4
                rdlong  59,t
                add     t,#4
                rdlong  60,t
                add     t,#4
                rdlong  61,t
                add     t,#4
                rdlong  62,t
                add     t,#4
                rdlong  63,t
                add     t,#4
                rdlong  64,t

readline_ret    ret
