'
' XGA_SYNC - initial SYNC generator cog for XGA driver v0.80
'
' Copyright 2009 William Henning
'
' http://Mikronauts.com
'
' mikronauts@gmail.com
'
' LICENSE
'
' XGA_SYNC is licensed for distribution in one of two ways:
'
' GPL v2.0 - which means that you must also distribute the source code to your application under the GPL
'
' Here is a link to the terms of the GPL v2.0: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
'
' -or-
'
' If you don't want to distribute your source code you can contact me for a commercial license - this means
' that you will have to pay a reasonable licensing fee if you do not wish to freely release your source code.
'
' I will gladly accept improvements to the drivers, however I ask that I can dual license the improved drivers
' as detailed above, and of course I will give you credit in the source and documentation for any of your
' improvements that I use.
'
' Please Note: You may not remove or modify these terms from any of the files or documentation.
'
' CREDITS:
'
' Chip Gracey for the Propeller and multi-cog video synchronization example code
'
' ariba, jazzed, PhiPi and lonesock from the forums for a great fast way of building longs from 8 bit inputs
' see the original thread at http://forums.parallax.com/forums/default.aspx?f=25&p=1&m=349679
'
' Hanno for making ViewPort that helped me debug Morpheus
'
'

CON

' 1024x768 settings - signals as 1024 x 768 @ 60Hz

'  hp = 1024     'horizontal pixels
'  hf = 24       'horizontal front porch pixels
'  hs = 136      'horizontal sync pixels
'  hb = 160      'horizontal back porch pixels

'  vp = 768      'vertical pixels
'  vf = 3        'vertical front porch lines
'  vs = 6        'vertical sync lines
'  vb = 9'29     'vertical back porch lines

  pr = 55        'pixel rate in MHz at 80MHz system clock (5MHz granularity)

{

1024x768 @ 60Hz

1024 active pixels = 1260    = 15.75us
  24 hfp           =  29.53  =   .40us
 136 hsync         = 167.38  =  2.10us
 160 hbp           = 197     =  2.46us
                               -------
                               20.71us
----
1344 pix

 768 active lines
   3 vfp
   6 vsync
  29 vbp
----
 806 lines

806 lines x 1344 pix x 60Hz = 64995840 dots per sec, ie 65MHz

1344 pix / 65M = 20.6769us whole line, * 80 = 1092 ticks
               = 15.7538us active pixel time = 
               = 15.3846ns/pixel
               = 246.1538ns/16pix

For some unknown reason 55MHz, with a 54Hz refresh, sync's up MUCH better

}

var

  long cog, sargs[4]

PUB start(SyncPtr,xaddr) : okay | i

  sargs[0] := SyncPtr  ' randevouz time
  sargs[1] := sargs[0] + 208*1024 '  1ms for VCO to stabilize
  sargs[2] := xaddr
  sargs[3] := 0   ' sync cog
    
  cog := cognew(@synccog,@sargs[0])

DAT

' 1024x768x4 color driver, sync engine

                        org                     'set origin to $000 for start of program

' Initialization code - init I/O
                                                                                              

synccog         mov     argptr,par
                rdlong  startdelay,argptr
                add     argptr,#4
                rdlong  vcodelay,argptr
                add     argptr,#4
                rdlong  buffer,argptr
                add     argptr,#4
                rdlong  oddeven,argptr wz
                mov     outa,#0
                or      oddeven,#0 wz

' **************************************************************************************

even_lines      mov     dira,syncpins           ' set for output
                movi    frqa,#(pr / 5) << 3     'set pixel rate - note the hidden 5MHz xtal dependancy! Will fix
'                movi    frqa,#12 << 3     'set pixel rate - note the hidden 5MHz xtal dependancy! Will fix
                mov     vcfg,sync_vcfg          'set video configuration
                mov     vscl,#1
                waitcnt startdelay,#0
                movi    ctra,#%00001_101        'enable PLL in ctra (VCO runs at 4x)
                waitcnt vcodelay,#0
                mov     vscl,#100
                mov     phsa, #0
                waitvid highsync,#0

next_frame      mov     count_active,   active_lines
                mov     count_vbp,      vbp_lines
                mov     count_vsync,    vsync_lines
                mov     count_vfp,      vfp_lines
                
activevid       mov     vscl,act_vscl
                waitvid highsync, #0


' scan line equivalent, addr goes here
                mov     t, fetch_line
                sub     t, count_active
                shl     t,#8
                add     t, rambase
                wrlong  t, buffer
' end of scan line

                mov     vscl,fp_vscl
                waitvid highsync, #0

                mov     vscl,hs_vscl
                waitvid hsvalue, #0

                mov     vscl, bp_vscl
                waitvid highsync, #0
                djnz    count_active, #activevid

                wrlong  rambase, buffer
                
vert_fp         mov     vscl,act_vscl
                waitvid highsync, #0

                mov     vscl,fp_vscl
                waitvid highsync, #0

                mov     vscl,hs_vscl
                waitvid hsvalue, #0

                mov     vscl, bp_vscl
                waitvid highsync, #0
                djnz    count_vbp, #vert_fp
                
' later plot pixels or chars during this time
'
'vert_sync       mov     vscl,vs_vscl
'                waitvid vs_value,#0
'                djnz    count_vsync,#vert_sync                        

vert_sync       mov     vscl,reg_vscl
                mov     t,#64
vsl1            waitvid vs_value, #0
                djnz    t,#vsl1
                
                mov     vscl,fp_vscl
                waitvid vs_value, #0
                mov     vscl,hs_vscl
                waitvid hsvs_value, #0
'                waitvid vs_value, #0
                mov     vscl, bp_vscl
                waitvid vs_value, #0
                djnz    count_vsync, #vert_sync
                
vert_bp         mov     vscl,act_vscl
                waitvid highsync, #0

                mov     vscl,fp_vscl
                waitvid highsync, #0

                mov     vscl,hs_vscl
                waitvid hsvalue, #0

                mov     vscl, bp_vscl
                waitvid highsync, #0
                djnz    count_vfp, #vert_bp



                jmp     #next_frame

'*****************************************************************************

'zero            long 0
argptr          long 0
startdelay      long 800_000
vcodelay        long 80_000
buffer          long 0
oddeven         long 0

highsync        long $03030303 ' pin24&25, low bits, are vs & hs respectively

sync_vcfg       long    %0_01_1_0_0_000_00000100000_011_0_00000011 ' P24,P25 Vsync, Hsync
vid_vcfg        long    %0_01_1_0_0_000_00000100000_010_0_11111111 ' P16-P23 RRRGGGBB data

reg_vscl        long    $00001000+16
act_vscl        long    $1000+1024
fp_vscl         long    $1000+24  
hs_vscl         long    $1000+136     
bp_vscl         long    $1000+160 
vs_vscl         long    1344 

hsvalue         long    %11111101_11111101_11111101_11111101
vs_value        long    %11111110_11111110_11111110_11111110
hsvs_value      long    %11111100_11111100_11111100_11111100

active_lines    long    768
fetch_line      long    769
rambase         long    $20_0000
vbp_lines       long    3
vsync_lines     long    6
vfp_lines       long    29    

count_active    long    0
count_vbp       long    0
count_vsync     long    0
count_vfp       long    0

vidpins         long    $00FF0000
syncpins        long    $03000000

blackvid        long    $00000000
whitevid        long    $00FF0000
rgb             long    $E01C0300

allones         long    $ffffffff
truecolor       long    %00000000_01010101_10101010_11111111
t               long
yexp            long    1

line            long    0[64]
