'
' XMM_GPU - Graphics Driver for Morpheus v0.80
'
' Still needs optimization and more features, but it works well enough to support some demos
'
' Copyright 2009 William Henning
'
' http://Mikronauts.com
'
' mikronauts@gmail.com
'
' LICENSE
'
' XMM_GPU is licensed for distribution in one of two ways:
'
' GPL v2.0 - which means that you must also distribute the source code to your application under the GPL
'
' Here is a link to the terms of the GPL v2.0: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
'
' -or-
'
' If you don't want to distribute your source code you can contact me for a commercial license - this means
' that you will have to pay a reasonable licensing fee if you do not wish to freely release your source code.
'
' I will gladly accept improvements to the drivers, however I ask that I can dual license the improved drivers
' as detailed above, and of course I will give you credit in the source and documentation for any of your
' improvements that I use.
'
' Please Note: You may not remove or modify these terms from any of the files or documentation.
'
' CREDITS:
'
' Chip Gracey for the Propeller and multi-cog video synchronization example code
'
' ariba, jazzed, PhiPi and lonesock from the forums for a great fast way of building longs from 8 bit inputs
' see the original thread at http://forums.parallax.com/forums/default.aspx?f=25&p=1&m=349679
'
' Hanno for making ViewPort that helped me debug Morpheus
'
'  

CON

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000

  MEMSIZE = 512*1024
  MEMLIMIT = MEMSIZE-1
  RAMBASE = $20_0000

OBJ
   sync: "xga_sync"             ' XGA h/v sync generation cog
   vga0: "xga_disp"             ' XGA odd/even scan line display cogs
   vga1: "xga_disp"             ' XGA odd/even scan line display cogs
  acog0: "xmm_addr"             ' address generation cog for burst reads 0,128,1,129,2,130....254,255
  rcog1: "xmm_read"             ' read bytes 0..127 into scan line buffer
  rcog2: "xmm_read"             ' read bytes 128..255 into scan line buffer

VAR

  long id, time, pencol, fontmask


DAT

debug   long 0[32]
line1   long $AAAAAAAA[64]      ' scan line buffers
line2   long $FFFFFFFF[64]      ' scan line buffers
colors  long $E01C0300[768]     ' future palette - one four color entry per scan line
rtime   long 0                  ' randevouz time
xaddr   long 0                  ' XMM address
haddr   long 0                  ' HUB address
linaddr long 0                  ' scan line address
textscr byte 0[128*64]          ' text screen buffer

PUB start | i

  haddr := @line1                ' start address of two 256 byte scan line buffers

  acog0.start(@xaddr,haddr,@rtime,@linaddr)  ' start the address generation cog first
  rcog1.start(10,haddr,@rtime,0,@linaddr)    ' 0=even cog
  rcog2.start(14,haddr,@rtime,1,@linaddr)    ' 1=odd cog

  'start vga
  time:=cnt + 800_000         ' set a randevouz time 10ms in the future
  haddr := @line1             ' point the vga display cogs at the line buffer

  sync.start(time,@xaddr)       ' start the sync generation cog
  vga0.start(time,haddr,0,@colors)      ' start the even line cog
  vga1.start(time,haddr,1,@colors)      ' start the odd line cog

  id :=cognew(@pread,@cmdx)

  waitcnt(cnt+160_000_000)

PUB SetPalette(yp,clr,r,g,b)
  byte[@colors[yp]][clr]:=((r&7)<<5)+((g&7)<<2)+(b&3)

PUB SetPaletteRange(y1,y2,c2,r,g,b)|iy
  repeat iy from y1 to y2
    SetPalette(iy,c2,r,g,b)

PUB FillPalette(c1,r,g,b)
  SetPaletteRange(0,yrez-1,c1,r,g,b)

PUB WaitMS(n)
  waitcnt(cnt+n*80_000) ' UGLY CRYSTAL DEPENDANCY HERE!!!

PUB plotc(xsrc,ydst,col)
  arg1 := xsrc
  arg2 := ydst
  arg3 := col
  repeat until (cmdx == 0)
  cmdx := 3 'cmdnum               ' triggers server, must be set last

PUB putb(xsrc,ydst,col)
  arg1 := xsrc
  arg2 := ydst
  arg3 := col
  repeat until (cmdx == 0)
  cmdx := 2 'cmdnum               ' triggers server, must be set last

PUB plot(xsrc,ydst)
  arg1 := xsrc
  arg2 := ydst
  repeat until (cmdx == 0)
  cmdx := 3 'cmdnum               ' triggers server, must be set last

PUB Pen(col)
  pencol := col & 3
  fontmask := (col << 6) + (col << 4) + (col << 2) + col
  arg3 := col
  pencol := col
  repeat until (cmdx == 0)
  cmdx := 4

PUB Cls(col)
  arg3 := col
  repeat until (cmdx == 0)
  cmdx := 5

PUB PutChar(xsrc,ysrc,ch)|yp,ptr
  arg1 := xsrc
  arg2 := ysrc
  arg4 := ch
  repeat until (cmdx == 0)
  cmdx := 7 'cmdnum

PUB PutStr(xsrc,ysrc,strptr)|sx,sl,bp,stx
  PutBytes(xsrc,ysrc,strptr,strsize(strptr))

PUB PutBytes(xsrc,ysrc,bptr,bsiz)
  arg1 := xsrc
  arg2 := ysrc
  arg4 := bptr
  arg5 := bsiz
  repeat until (cmdx == 0)
  cmdx := 8 'cmdnum

PUB PutScreen
  repeat until (cmdx == 0)
  cmdx := 9 'cmdnum

PUB FillScreen(ch)
  bytefill(@textscr,ch,xchars*ychars)

PUB hline(xsrc,ysrc,xtwo)|xt
  arg1 := xsrc
  arg2 := ysrc
  arg4 := xtwo
  if ((xtwo-xsrc)<5)               ' i am not sure really short lines worth the cog space for pasm
    repeat xt from xsrc to xtwo
      plot(xt,ysrc)
  else
    repeat until (cmdx == 0)
    cmdx := 6 'cmdnum
    repeat until (cmdx == 0)

' See http://en.wikipedia.org/wiki/Bresenham's_line_algorithm for more info
PUB Line(x0,y0,x1,y1)|x2,y2

  steep := ||(y1 - y0) > ||(x1 - x0)

  if steep
    t  := x0
    x0 := y0
    y0 := t
    t  := x1
    x1 := y1
    y1 := t

  if x0 > x1
    t  := x0
    x0 := x1
    x1 := t
    t  := y0
    y0 := y1
    y1 := t

  dx := x1 - x0
  dy := ||(y1-y0)
  e  := dx/2

  if y0<y1
    ys := 1
  else
    ys := -1

  y2  := y0

  repeat x2 from x0 to x1
    if steep
      plot(y2,x2)
    else
      plot(x2,y2)
    e -= dy
    if e<0
      y2+=ys
      e+=dx

PUB DrawRect(x2,y2,w,h)|xw,yh
  xw := x2+w-1
  yh := y2+h-1
  hline(x2,y2,xw)
  hline(x2,yh,xw)
  repeat t from y2 to yh
    plot(x2,t)
    plot(xw,t)

PUB FilledRect(x2,y2,w,h)|tx,ty,ty2
  tx := x2+w-1
  if (tx => xrez)
    tx := xrez-1
  ty2 := y2+h-1
  if (ty2 => yrez)
    ty2 := yrez-1
  repeat ty from y2 to ty2
    hline(x2,ty,tx)

PUB DrawCircle(x0,y0,r)|f,ddF_x,ddF_y,x2,y2
  if r < 2
    plot(x0,y0)
    return
  f     := 1 - r
  ddF_x := 1
  ddF_y := -2 * r
  x2    := 0
  y2    := r
  plot(x0,y0+r)
  plot(x0,y0-r)
  plot(x0+r,y0)
  plot(x0-r,y0)
  repeat while x2<y2
    if f => 0
      y2--
      ddF_y += 2
      f     += ddF_y
    x2++
    ddF_x += 2
    f     += ddF_x
    plot(x0 + x2 , y0 + y2)
    plot(x0 - x2 , y0 + y2)
    plot(x0 + x2 , y0 - y2)
    plot(x0 - x2 , y0 - y2)
    plot(x0 + y2 , y0 + x2)
    plot(x0 - y2 , y0 + x2)
    plot(x0 + y2 , y0 - x2)
    plot(x0 - y2 , y0 - x2)

PUB FilledCircle(x0,y0,r)|f,ddF_x,ddF_y,x2,y2
  if r < 2
    return
  f     := 1 - r
  ddF_x := 1
  ddF_y := -2 * r
  x2    := 0
  y2    := r
  line(x0,y0+r,x0,y0-r)
  hline(x0-r,y0,x0+r)

  repeat while x2<y2
    if f => 0
      y2--
      f+=(ddF_y+=2)
    x2++
    f+=(ddF_x+=2)
    hline(x0 - x2 , y0 + y2, x0 + x2)
    hline(x0 - x2 , y0 - y2, x0 + x2)
    hline(x0 - y2 , y0 + x2, x0 + y2)
    hline(x0 - y2 , y0 - x2, x0 + y2)

PUB config(drawscreen,xres,yres,bitsperpix)
  if (bitsperpix<>2)
    if (bitsperpix<>8)
      bitsperpix:=2  ' force 2bpp for now as only 2 and 8 bpp supported
  drawb:=drawscreen>>8
  lineb:=(xres*bitsperpix)>>3
  pixb:=bitsperpix
  xrez:=xres
  yrez:=yres
  xchars:=xres>>3
  ychars:=yres/12
  font_ptr:=@font_table
  textbuffer:=@textscr

PUB stop
  cogstop(id)

dat

        org 0
        
pread   jmp   #xinit     '0
        jmp   #rdb       '1
        jmp   #wrb       '2
        jmp   #plotpix   '3
        jmp   #setpen    '4
        jmp   #clsc      '5
        jmp   #hlineh    '6
        jmp   #putchr    '7
        jmp   #putstring '8
        jmp   #textrefresh '9

drawb   long  $2000     ' base address of the screen we are drawing on
lineb   long  200       ' number of bytes per line
pixb    long  2         ' number of bits per pixel
xrez    long  800       ' number of pixels per line
yrez    long  600       ' number of lines on the screen
xchars  long  100
ychars  long  50

cmd     long  0
temp    long  0

x       long  0
y       long  0
c       long  0
xx      long  0
yy      long  0

count   long  0

coltable
zero    long  0
oneone  long  %01010101
twotwo  long  %10101010
threes  long  %11111111
allones long  $FFFFFFFF

xmask   long  %00000011_11111100
ymask   long  %00000011_11111111

ctrl    long $0C00_0000
bsel    long $0C00_FFFF
rsel    long $0800_FF00
wsel    long $0400_FFFF

page    long 0
offs    long 0
data    long 0

args    long  0

cmdx                    ' command to xmm_server, 0=command complete, waiting for new cmd
cmdptr  long  0         ' pointer to command byte

arg1
xptr    long  0         ' x coordinate pointer

arg2
yptr    long  0         ' y coordinate pointer

arg3
x2ptr   long  0

arg4
y2ptr   long  0

arg5
cptr    long  0         ' argument ptr

arg6
lenptr  long  0

arg7
tmpptr  long  0


font_ptr      long      0

'----------------------------------------------------------------------
' initialize server pointers
'----------------------------------------------------------------------

xinit   mov    args,  par
        mov   cmdptr, args
        add   args,#4
        mov   xptr, args ' arg1 - xptr
        add   args,#4
        mov   yptr, args ' arg2 - yptr
        add   args,#4
        mov   cptr, args ' arg3 - x2ptr
        add   args,#4
        mov   x2ptr, args ' arg4 - y2ptr
        add   args,#4
        mov   y2ptr, args ' arg5 - cptr
        add   args,#4
        mov   lenptr, args ' arg6 - lenptr

'----------------------------------------------------------------------
' command loop - wait for command code, then vector to it
'----------------------------------------------------------------------

cloop   rdlong cmd, cmdptr wz
  if_z  jmp  #cloop
        jmp   cmd               ' jump to address held in cmd

'----------------------------------------------------------------------
' getxyc      Pick up arguments
'----------------------------------------------------------------------

getxyc  rdlong y, yptr          ' get y coordinate
        rdlong x, xptr          ' get the raw x coordinate
        rdlong c, cptr

setxyc  and   y, ymask
        add   y, drawb         ' add draw base address to i

        mov   offs,x
        and   offs,xmask
        shl   offs,#6           ' now compute byte offset

        and   x,#3
        shl   x,#1

        mov   data,#3
        shl    data,x           ' finish making the mask

        and    c, #3            ' make sure color is valid
        shl    c, x             ' now we have the color mask!
setxyc_ret
getxyc_ret    ret

'----------------------------------------------------------------------
' SETPEN(c)
'----------------------------------------------------------------------

setpen  call  #getxyc
        wrlong zero, cmdptr
        jmp   #cloop    ' color set up in handler

'----------------------------------------------------------------------
' CLS(c)
'----------------------------------------------------------------------

clsc    call  #getcolbyte

        mov   count,yrez
        mov   y,drawb

nextrow mov   temp, #32
        mov   offs, data ' #0


ls2     lockset zero wc
  if_c  jmp   #ls2

        mov   outa,y
        nop
        mov   dira, bsel wz     ' enable outputs  sets Z=0
        nop
        muxz  dira, ctrl
        nop
        nop   ' xga needs 2nd nop here

        mov   outa,offs
        nop
        mov   dira, wsel wz

        add   outa,#$100
        add   outa,#$100
        add   outa,#$100

        add   outa,#$100
        add   outa,#$100
        add   outa,#$100
        add   outa,#$100

        nop
        add   offs,postinc
        mov   dira,#0

        lockclr zero

        djnz  temp,#ls2

        add   y, #1             'nop ' required
        djnz  count,#nextrow

        wrlong zero, cmdptr
        jmp   #cloop    ' color set up in handler

postinc long    $800

'----------------------------------------------------------------------
' GETCOLBYTE
'----------------------------------------------------------------------

getcolbyte
        rdlong data, cptr
        and    data,#3
        add    data,#coltable
        movs   getcol2,data
        nop
getcol2 mov    data,0

getcolbyte_ret
        ret

'----------------------------------------------------------------------
' PARSEX1
'----------------------------------------------------------------------

parsex1 mov   x1bits,x
        and   x1bits,#3
        shr   x,#2
        and   x,#255
        shl   x,#8
parsex1_ret ret

'----------------------------------------------------------------------
' PARSEX1
'----------------------------------------------------------------------

parsex2 mov   x2bits,xx
        and   x2bits,#3
        shr   xx,#2
        and   xx,#255
        shl   xx,#8
parsex2_ret ret

'----------------------------------------------------------------------
' SORTX1X2
'----------------------------------------------------------------------

sortx1x2 cmp   x,xx wc   ' if xx<x swap them
 if_nc  mov   temp,x
 if_nc  mov   x,xx
 if_nc  mov   xx,temp
sortx1x2_ret ret

'----------------------------------------------------------------------
' PARSEY1
'----------------------------------------------------------------------

parsey1 rdlong y,yptr
        and    y,ymask
        add    y,drawb
parsey1_ret ret

'----------------------------------------------------------------------
' HLINE(x,y,x2)
'----------------------------------------------------------------------
' Starting
' 0         1         2         3         x1bits
' 11111111  00111111  00001111  00000011  <-- starting, monitor view
' 11111111  11111100  11110000  11000000  <-- memory view, bits reversed, starting
'
' example, line starting 0, ending 1
' screen view  11111111 & 11110000 --> 11110000

' Ending
' 0         1         2         3         x2bits
' 11000000  11110000  11111100  11111111  <-- ending, monitor view, ending
' 00000011  00001111  00111111  11111111  <-- memory view, bits reversed, ending
'$FF000000
'
' example, line starting 1, ending 2
' screen view  00111111 & 11111100 --> 00111100


optmask long  $FF000000
inmask  long  $0000FFFF
outmask long  $0000FF00

hlen    long  0
x1bits  long  0
x2bits  long  0

b1      long  0
b2      long  0

hlineh  call  #parsey1

        rdlong x,xptr
        rdlong xx,x2ptr
        call  #sortx1x2

        call  #parsex1
        mov   b1,#$ff
        shl   b1,x1bits
        shl   b1,x1bits
        and   b1,#$ff

        call  #parsex2
        mov   b2,optmask
        rol   b2,x2bits
        rol   b2,x2bits
        and   b2,#$ff

        call  #getcolbyte ' returns color byte in data

ls3a    lockset zero wc
  if_c  jmp   #ls3a

        mov   outa, y           ' set up page address
        mov   dira, bsel wz     ' enable outputs  sets Z=0
        mov   offs,x
        muxz  dira, ctrl
        nop   ' xga needs 2nd nop here
        nop

        ' Output low byte of address for starting byte
        mov   outa, offs        ' output it
        nop
        mov   dira, rsel        'nop apparently not required after this mov
        or    zero,#1 nr,wz     ' CLRZ,   SETZ would be xor 0,0 nr,wz
        nop

        mov   temp, ina
        and   temp, inmask      ' isolate the bits we will keep from memory
        muxz  dira, ctrl        ' end of read
        nop   ' xga needs 2nd nop here
        nop                     ' required or messes up address latch, looks like 100ns delay req b4 outa

        andn  temp,b1
        and   b1,data
        or    temp,b1

        mov   outa, temp        ' output it
        mov   dira, wsel wz     'nop apparently not required after this mov
        nop
        mov   dira, #0

        lockclr zero

        rdlong temp, xptr       ' waste a hub cycle on purpose

ls3b    lockset zero wc
  if_c  jmp   #ls3b

        mov   outa, y           ' set up page address
        mov   dira, bsel wz     ' enable outputs  sets Z=0
        mov   offs,x
        muxz  dira, ctrl
        nop   ' xga needs 2nd nop here
'        nop

        ' Output low byte of address for ending byte
        mov   offs, xx          ' get starting byte offset
        mov   outa, offs        ' output it
        nop
        mov   dira, rsel        'nop apparently not required after this mov
        or    zero,#1 nr,wz     ' CLRZ,   SETZ would be xor 0,0 nr,wz

        mov   temp, ina
        and   temp, inmask      ' isolate the bits we will keep from memory
        muxz  dira, ctrl        ' end of read
'        nop   ' xga needs 2nd nop here
'        nop                     ' required or messes up address latch, looks like 100ns delay req b4 outa

        andn  temp,b2
        and   b2,data
        or    temp,b2

        mov   outa, temp        ' output it
        nop
        mov   dira, wsel        'nop apparently not required after this mov

        lockclr zero
        mov   dira, #0

        '--------------------------------------------------------------
        ' Write full bytes in the middle
        '--------------------------------------------------------------

        sub   xx,#$100

rest    cmp   x, xx wz, wc
 if_ae  jmp   #done

        add   x, #$100

        mov   offs, x
        or    offs, data

do_full lockset zero wc
  if_c  jmp   #do_full

        mov   outa,y
        nop
        mov   dira, bsel wz     ' enable outputs  sets Z=0
        nop
        muxz  dira, ctrl

        nop
        nop

        mov   outa,offs
        mov   dira, wsel wz
        nop
        mov   dira,#0

        lockclr zero

        jmp   #rest

        jmp   #done

'----------------------------------------------------------------------
' PLOTPIX(x,y,col)
'----------------------------------------------------------------------

plotpix call  #getxyc
        call  #cogplot
done    wrlong zero, cmdptr
        jmp   #cloop    ' color set up in handler

'----------------------------------------------------------------------
' COGPLOT - support routine for future PASM Line() routine
'
' assumes x,y,c already set up
'----------------------------------------------------------------------

cogplot

        mov   outa, y

ls      lockset zero wc
  if_c  jmp   #ls

        ' Set the page register

        mov   dira, bsel wz     ' enable outputs  sets Z=0
'        nop ' required
        nop ' required

        muxz  dira, ctrl        ' end bank select
        nop ' required
        nop ' required with Mem+ attached due to increased capacitance on data bus

        mov   outa, offs        ' output low byte of address
'        nop ' required with Mem+ attached due to increased capacitance on data bus
'        nop ' required with Mem+ attached due to increased capacitance on data bus

        mov   dira, rsel        'nop apparently not required after this mov
        nop ' required with Mem+ attached due to increased capacitance on data bus
'        nop ' required with Mem+ attached due to increased capacitance on data bus

        mov   temp, ina wz
        andn  temp, data         ' clear pixel first
        and   temp,#$ff

        muxz  dira, ctrl

        or    temp, c            ' or in new color
        or    temp,offs         ' add back the address

        mov   outa,temp
        mov   dira,wsel
'        nop
'        nop

        lockclr zero
        mov   dira,zero

cogplot_ret   ret

'----------------------------------------------------------------------
' LINE(x1,y1,x2,y2)
'----------------------------------------------------------------------

steep	long	0
t	long	0
dx	long	0
dy	long	0
e	long	0
ys	long	0

'swp     long    0

'----------------------------------------------------------------------
' RDBYTE command
'----------------------------------------------------------------------

rdb
        jmp  #cloop

'----------------------------------------------------------------------
' WRBYTE command
'----------------------------------------------------------------------

wrb
        rdlong y, yptr          ' get y coordinate
        rdlong x, xptr          ' get the raw x coordinate
        rdlong c, cptr

        and   y, ymask
        add   y, drawb         ' add draw base address to i

        mov   offs,x
        and   offs,xmask
        shl   offs,#6           ' now compute byte offset

        or    offs,c            ' add in byte

wrbl    lockset zero wc
  if_c  jmp   #wrbl

        ' Set the page register
        mov   outa, y
        mov   dira, bsel wz     ' enable outputs  sets Z=0
        nop ' required
        muxz  dira, ctrl
        nop ' required
        nop   ' required for xga
        ' Output low byte of address

        mov   outa,offs
        mov   dira,wsel
        mov   dira,zero
        lockclr zero

        jmp   #done

' simple optimization: if Y = last Y, and we are still in same window
' no need to compute page or set it! (track write window to do this)

'----------------------------------------------------------------------
' PUTCHAR(x,y,ch)
'----------------------------------------------------------------------

putchr  rdlong x,arg1
        rdlong y,arg2          ' get y coordinate
        call  #getcolbyte ' data is color mask, for now output the char mask
        rdlong xx,x2ptr   ' char in arg4, which is y2ptr
        call  #prichar
        jmp   #done

'----------------------------------------------------------------------
' PUTSTR(x,y,byteptr,numchars)
'----------------------------------------------------------------------

putstring
        rdlong x,arg1
        rdlong y,arg2
        call  #getcolbyte

        rdlong byteptr, x2ptr
        rdlong strlen, y2ptr

putloop rdbyte xx, byteptr
        add   byteptr,#1
        call  #prichar
        sub   y,#12
        add   x,#8
        djnz  strlen,#putloop

        jmp   #done

byteptr long 0
strlen  long 0

'----------------------------------------------------------------------
' TEXTREFRESH
'----------------------------------------------------------------------

textbuffer    long      0
maxlines      long      0
lxc           long      0
lyc           long      0
px            long      0
py            long      0

textrefresh
        call  #getcolbyte

        mov   byteptr,textbuffer
        mov   lxc,#128 'xchars
        mov   lyc,#64

tlpc2   mov   x,lxc

tlpc    mov   x,#128
        sub   x,lxc
        shl   x,#3

        mov   y,#64
        sub   y,lyc
        shl   y,#2
        mov   temp,y
        add   y,temp
        add   y,temp

        rdlong xx, byteptr
        add   byteptr,#1
        call  #prichar

        djnz  lxc,#tlpc
        djnz  lyc,#tlpc2

        jmp   #done

prichar
	and   xx,#$80 nr,wz ' if high bit set, make xor mask $ff so font inverted later
 if_z	mov   yy,#0
 if_nz	mov   yy,#$ff

        and   xx,#127   ' confine char to lower part of ascii
        shl   xx,#3     ' multiply by 24
        mov   temp,xx
        shl   xx,#1
        add   xx,temp
        add   xx,font_ptr ' we have the char address!

        and   y, ymask
        add   y, drawb         ' add draw base address to i

        shr   x,#2
        and   x,#255
        shl   x,#8           ' now compute byte offset
        mov   offs,x

        ' at this point:
        '     y points at first line of screen mem for char
        '  offs points at first byte on the line where we need to put a byte
        '    xx points to the first byte of the first line of the character definition

        mov   count,#12          ' there are 12 lines in the character
'--
loopchar
        rdbyte b1,xx
        add   xx,#1             '        nop slot
'--
        rdbyte b2,xx
        add   xx,#1
        mov   outa, y           ' Set the page register
'--

wrch    lockset zero wc
  if_c  jmp   #wrch
        ' wasted time slot
        mov   dira, bsel wz     ' enable outputs  sets Z=0
'--
        xor   b1, yy            '        nop slot
        and   b1,data
        muxz  dira, ctrl
        or    b1, offs
'--
        add   y,#1
        mov   outa,b1
        mov   dira,wsel
        xor   b2, yy
'--
        and   b2,data
        or    b2,offs
        add   b2,#$100        ' go to next byte address
        mov   outa,b2
'--
        lockclr zero
        mov   dira,zero
        djnz  count,#loopchar
'--
        shr   x,#6
prichar_ret ret

        FIT 496

'----------------------------------------------------------------------
' FONT DATA
'----------------------------------------------------------------------

DAT

font_table
' Char $00 ' '
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3333, %%3333	' xxxxxxxx
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
' Char $01 ' '
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3333, %%3333	' xxxxxxxx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
' Char $02 ' '
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3333, %%3333	' xxxxxxxx
' Char $03 ' '
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3333, %%3333	' xxxxxxxx
' Char $04 ' '
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
' Char $05 ' '
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
' Char $06 ' '
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3333, %%3333	' xxxxxxxx
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $07 ' '
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3333, %%3333	' xxxxxxxx
' Char $08 ' '
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
' Char $09 ' '
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3333, %%3333	' xxxxxxxx
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $0a ' '
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
' Char $0b ' '
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
' Char $0c ' '
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3333, %%0003	' xxxxx...
        byte %%3333, %%0003	' xxxxx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
' Char $0d ' '
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3333, %%3333	' xxxxxxxx
        byte %%3333, %%3333	' xxxxxxxx
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $0e ' '
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%3333	' ...xxxxx
        byte %%3000, %%3333	' ...xxxxx
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
' Char $0f ' '
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3000, %%3333	' ...xxxxx
        byte %%3000, %%3333	' ...xxxxx
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
' Char $10 ' '
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3333, %%0003	' xxxxx...
        byte %%3333, %%0003	' xxxxx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
' Char $11 ' '
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3333, %%0003	' xxxxx...
        byte %%3333, %%0003	' xxxxx...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $12 ' '
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%0003	' ...xx...
        byte %%3000, %%3333	' ...xxxxx
        byte %%3000, %%3333	' ...xxxxx
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $13 ' '
        byte %%0000, %%3333	' ....xxxx
        byte %%3300, %%3333	' ..xxxxxx
        byte %%3330, %%0000	' .xxx....
        byte %%0333, %%0000	' xxx.....
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
' Char $14 ' '
        byte %%3333, %%0000	' xxxx....
        byte %%3333, %%0033	' xxxxxx..
        byte %%0000, %%0333	' ....xxx.
        byte %%0000, %%3330	' .....xxx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
' Char $15 ' '
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3300	' ......xx
        byte %%0000, %%3330	' .....xxx
        byte %%0000, %%0333	' ....xxx.
        byte %%3333, %%0033	' xxxxxx..
        byte %%3333, %%0000	' xxxx....
' Char $16 ' '
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0033, %%0000	' xx......
        byte %%0333, %%0000	' xxx.....
        byte %%3330, %%0000	' .xxx....
        byte %%3300, %%3333	' ..xxxxxx
        byte %%0000, %%3333	' ....xxxx
' Char $17 ' '
        byte %%0000, %%3300	' ......XX
        byte %%0000, %%3300	' ......XX
        byte %%0000, %%0330	' .....XX.
        byte %%0000, %%0330	' .....XX.
        byte %%0000, %%0033	' ....XX..
        byte %%3000, %%0003	' ...XX...
        byte %%3000, %%0003	' ...XX...
        byte %%3300, %%0000	' ..XX....
        byte %%0330, %%0000	' .XX.....
        byte %%0330, %%0000	' .XX.....
        byte %%0033, %%0000	' XX......
        byte %%0033, %%0000	' XX......
' Char $18 ' '
        byte %%0033, %%0000	' XX......
        byte %%0033, %%0000	' XX......
        byte %%0330, %%0000	' .XX.....
        byte %%0330, %%0000	' .XX.....
        byte %%3300, %%0000	' ..XX....
        byte %%3000, %%0003	' ...XX...
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0033	' ....XX..
        byte %%0000, %%0330	' .....XX.
        byte %%0000, %%0330	' .....XX.
        byte %%0000, %%3300	' ......XX
        byte %%0000, %%3300	' ......XX
' Char $19 ' '
        byte %%0033, %%3300	' XX....XX
        byte %%0033, %%3300	' XX....XX
        byte %%0330, %%0330	' .XX..XX.
        byte %%0330, %%0330	' .XX..XX.
        byte %%3300, %%0033	' ..XXXX..
        byte %%3000, %%0003	' ...XX...
        byte %%3000, %%0003	' ...XX...
        byte %%3300, %%0033	' ..XXXX..
        byte %%0330, %%0330	' .XX..XX.
        byte %%0330, %%0330	' .XX..XX.
        byte %%0033, %%3300	' XX....XX
        byte %%0033, %%3300	' XX....XX
' Char $1a ' '
        byte %%3333, %%3333	' XXXXXXXX
        byte %%3333, %%3333	' XXXXXXXX
        byte %%3333, %%3333	' XXXXXXXX
        byte %%3333, %%3333	' XXXXXXXX
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $1b ' '
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3333, %%3333	' XXXXXXXX
        byte %%3333, %%3333	' XXXXXXXX
        byte %%3333, %%3333	' XXXXXXXX
        byte %%3333, %%3333	' XXXXXXXX
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $1c ' '
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3333, %%3333	' XXXXXXXX
        byte %%3333, %%3333	' XXXXXXXX
        byte %%3333, %%3333	' XXXXXXXX
        byte %%3333, %%3333	' XXXXXXXX
' Char $1d ' '
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
' Char $1e ' '
        byte %%0003, %%0000	' X.......
        byte %%0033, %%0000	' XX......
        byte %%0333, %%0000	' XXX.....
        byte %%0333, %%0000	' XXX.....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0000	' XXXX....
        byte %%3333, %%0003	' XXXXX...
        byte %%3333, %%0003	' XXXXX...
        byte %%3333, %%0033	' XXXXXX..
        byte %%3333, %%0033	' XXXXXX..
        byte %%3333, %%0333	' XXXXXXX.
        byte %%3333, %%0333	' XXXXXXX.
' Char $1f ' '
        byte %%3300, %%0003	' ..XXX...
        byte %%3330, %%0033	' .XXXXX..
        byte %%3330, %%0033	' .XXXXX..
        byte %%3333, %%0333	' XXXXXXX.
        byte %%3333, %%0333	' XXXXXXX.
        byte %%3333, %%0333	' XXXXXXX.
        byte %%3333, %%0333	' XXXXXXX.
        byte %%3333, %%0333	' XXXXXXX.
        byte %%3330, %%0033	' .XXXXX..
        byte %%3330, %%0033	' .XXXXX..
        byte %%3300, %%0003	' ..XXX...
        byte %%0000, %%0000	' ........
' Char $20 ' '
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $21 '!'
        byte %%3300, %%0003	' ..XXX...
        byte %%3300, %%0003	' ..XXX...
        byte %%3300, %%0003	' ..XXX...
        byte %%3300, %%0003	' ..XXX...
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $22 '"'
        byte %%0030, %%0030	' .X...X..
        byte %%0030, %%0030	' .X...X..
        byte %%0030, %%0030	' .X...X..
        byte %%0030, %%0030	' .X...X..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $23 '#'
        byte %%0300, %%0003	' ..X.X...
        byte %%0300, %%0003	' ..X.X...
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0300, %%0003	' ..X.X...
        byte %%0300, %%0003	' ..X.X...
        byte %%0300, %%0003	' ..X.X...
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0300, %%0003	' ..X.X...
        byte %%0300, %%0003	' ..X.X...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $24 '$'
        byte %%3000, %%0000	' ...X....
        byte %%3330, %%0033	' .XXXXX..
        byte %%3003, %%0300	' X..X..X.
        byte %%3003, %%0000	' X..X....
        byte %%3330, %%0033	' .XXXXX..
        byte %%3000, %%0300	' ...X..X.
        byte %%3003, %%0300	' X..X..X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $25 '%'
        byte %%0030, %%0000	' .X......
        byte %%0303, %%0300	' X.X...X.
        byte %%0030, %%0330	' .X...XX.
        byte %%0000, %%0033	' ....XX..
        byte %%3000, %%0003	' ...XX...
        byte %%3300, %%0000	' ..XX....
        byte %%0330, %%0030	' .XX..X..
        byte %%0033, %%0303	' XX..X.X.
        byte %%0003, %%0030	' X....X..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $26 '&'
        byte %%3300, %%0000	' ..XX....
        byte %%0030, %%0003	' .X..X...
        byte %%0030, %%0003	' .X..X...
        byte %%3300, %%0000	' ..XX....
        byte %%3330, %%0000	' .XXX....
        byte %%0003, %%0303	' X...X.X.
        byte %%0003, %%0030	' X....X..
        byte %%0003, %%0003	' X...X...
        byte %%3330, %%0330	' .XXX.XX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $27 '''
        byte %%0000, %%0033	' ....XX..
        byte %%0000, %%0033	' ....XX..
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0003	' ....X...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $28 '('
        byte %%0000, %%0030	' .....X..
        byte %%3000, %%0003	' ...XX...
        byte %%3300, %%0000	' ..XX....
        byte %%0330, %%0000	' .XX.....
        byte %%0330, %%0000	' .XX.....
        byte %%0330, %%0000	' .XX.....
        byte %%3300, %%0000	' ..XX....
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $29 ')'
        byte %%0030, %%0000	' .X......
        byte %%3300, %%0000	' ..XX....
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0033	' ....XX..
        byte %%0000, %%0033	' ....XX..
        byte %%0000, %%0033	' ....XX..
        byte %%3000, %%0003	' ...XX...
        byte %%3300, %%0000	' ..XX....
        byte %%0030, %%0000	' .X......
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $2a '*'
        byte %%0000, %%0000	' ........
        byte %%3000, %%0000	' ...X....
        byte %%3030, %%0030	' .X.X.X..
        byte %%3300, %%0003	' ..XXX...
        byte %%3333, %%0333	' XXXXXXX.
        byte %%3300, %%0003	' ..XXX...
        byte %%3030, %%0030	' .X.X.X..
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $2b '+'
        byte %%0000, %%0000	' ........
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3333, %%0333	' XXXXXXX.
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $2c ','
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3300, %%0000	' ..XX....
        byte %%3300, %%0000	' ..XX....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0300, %%0000	' ..X.....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $2d '-'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $2e '.'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3300, %%0000	' ..XX....
        byte %%3300, %%0000	' ..XX....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $2f '/'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0330	' .....XX.
        byte %%0000, %%0033	' ....XX..
        byte %%3000, %%0003	' ...XX...
        byte %%3300, %%0000	' ..XX....
        byte %%0330, %%0000	' .XX.....
        byte %%0033, %%0000	' XX......
        byte %%0003, %%0000	' X.......
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $30 '0'
        byte %%3300, %%0003	' ..XXX...
        byte %%0030, %%0030	' .X...X..
        byte %%0003, %%0303	' X...X.X.
        byte %%0003, %%0303	' X...X.X.
        byte %%3003, %%0300	' X..X..X.
        byte %%0303, %%0300	' X.X...X.
        byte %%0303, %%0300	' X.X...X.
        byte %%0030, %%0030	' .X...X..
        byte %%3300, %%0003	' ..XXX...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $31 '1'
        byte %%3000, %%0000	' ...X....
        byte %%3300, %%0000	' ..XX....
        byte %%3330, %%0000	' .XXX....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $32 '2'
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0300	' ......X.
        byte %%3300, %%0033	' ..XXXX..
        byte %%0030, %%0000	' .X......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $33 '3'
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0300	' ......X.
        byte %%3300, %%0033	' ..XXXX..
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0300	' ......X.
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $34 '4'
        byte %%0000, %%0033	' ....XX..
        byte %%3000, %%0030	' ...X.X..
        byte %%0300, %%0030	' ..X..X..
        byte %%0030, %%0030	' .X...X..
        byte %%0003, %%0030	' X....X..
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0333	' ....XXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $35 '5'
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0300	' ......X.
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $36 '6'
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%3333, %%0033	' XXXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $37 '7'
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0003	' ....X...
        byte %%3000, %%0000	' ...X....
        byte %%0300, %%0000	' ..X.....
        byte %%0030, %%0000	' .X......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $38 '8'
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $39 '9'
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0333	' .XXXXXX.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0003	' ....X...
        byte %%3330, %%0000	' .XXX....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $3a ':'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3000, %%0003	' ...XX...
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3000, %%0003	' ...XX...
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $3b ';'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3000, %%0003	' ...XX...
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0000	' ........
        byte %%3000, %%0003	' ...XX...
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0003	' ....X...
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $3c '<'
        byte %%0000, %%0330	' .....XX.
        byte %%0000, %%0033	' ....XX..
        byte %%3000, %%0003	' ...XX...
        byte %%3300, %%0000	' ..XX....
        byte %%0330, %%0000	' .XX.....
        byte %%3300, %%0000	' ..XX....
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0033	' ....XX..
        byte %%0000, %%0330	' .....XX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $3d '='
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0000	' ........
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $3e '>'
        byte %%0330, %%0000	' .XX.....
        byte %%3300, %%0000	' ..XX....
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0033	' ....XX..
        byte %%0000, %%0330	' .....XX.
        byte %%0000, %%0033	' ....XX..
        byte %%3000, %%0003	' ...XX...
        byte %%3300, %%0000	' ..XX....
        byte %%0330, %%0000	' .XX.....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $3f '?'
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0003	' ....X...
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $40 '@'
        byte %%3300, %%0003	' ..XXX...
        byte %%0030, %%0030	' .X...X..
        byte %%3003, %%0303	' X..XX.X.
        byte %%0303, %%0330	' X.X..XX.
        byte %%0303, %%0330	' X.X..XX.
        byte %%0303, %%0030	' X.X..X..
        byte %%3003, %%0003	' X..XX...
        byte %%0030, %%0300	' .X....X.
        byte %%3300, %%0033	' ..XXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $41 'A'
        byte %%3300, %%0003	' ..XXX...
        byte %%0030, %%0030	' .X...X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $42 'B'
        byte %%3333, %%0033	' XXXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3333, %%0033	' XXXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3333, %%0033	' XXXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $43 'C'
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $44 'D'
        byte %%3333, %%0003	' XXXXX...
        byte %%0003, %%0030	' X....X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0030	' X....X..
        byte %%3333, %%0003	' XXXXX...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $45 'E'
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%3333, %%0033	' XXXXXX..
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $46 'F'
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%3333, %%0033	' XXXXXX..
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $47 'G'
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0333	' X...XXX.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $48 'H'
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $49 'I'
        byte %%3330, %%0033	' .XXXXX..
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $4a 'J'
        byte %%3300, %%0333	' ..XXXXX.
        byte %%0000, %%0003	' ....X...
        byte %%0000, %%0003	' ....X...
        byte %%0000, %%0003	' ....X...
        byte %%0000, %%0003	' ....X...
        byte %%0000, %%0003	' ....X...
        byte %%0003, %%0003	' X...X...
        byte %%0003, %%0003	' X...X...
        byte %%3330, %%0000	' .XXX....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $4b 'K'
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0030	' X....X..
        byte %%0003, %%0003	' X...X...
        byte %%3003, %%0000	' X..X....
        byte %%0333, %%0000	' XXX.....
        byte %%3003, %%0000	' X..X....
        byte %%0003, %%0003	' X...X...
        byte %%0003, %%0030	' X....X..
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $4c 'L'
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $4d 'M'
        byte %%0003, %%0300	' X.....X.
        byte %%0033, %%0330	' XX...XX.
        byte %%0303, %%0303	' X.X.X.X.
        byte %%0303, %%0303	' X.X.X.X.
        byte %%3003, %%0300	' X..X..X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $4e 'N'
        byte %%0003, %%0300	' X.....X.
        byte %%0033, %%0300	' XX....X.
        byte %%0303, %%0300	' X.X...X.
        byte %%0303, %%0300	' X.X...X.
        byte %%3003, %%0300	' X..X..X.
        byte %%3003, %%0300	' X..X..X.
        byte %%0003, %%0303	' X...X.X.
        byte %%0003, %%0303	' X...X.X.
        byte %%0003, %%0330	' X....XX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $4f 'O'
        byte %%3300, %%0003	' ..XXX...
        byte %%0030, %%0030	' .X...X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0030, %%0030	' .X...X..
        byte %%3300, %%0003	' ..XXX...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $50 'P'
        byte %%3333, %%0003	' XXXXX...
        byte %%0003, %%0030	' X....X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0030	' X....X..
        byte %%3333, %%0003	' XXXXX...
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $51 'Q'
        byte %%3300, %%0003	' ..XXX...
        byte %%0030, %%0030	' .X...X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3003, %%0300	' X..X..X.
        byte %%0003, %%0303	' X...X.X.
        byte %%0030, %%0030	' .X...X..
        byte %%3300, %%0303	' ..XXX.X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $52 'R'
        byte %%3333, %%0033	' XXXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0030	' X....X..
        byte %%3333, %%0003	' XXXXX...
        byte %%0003, %%0030	' X....X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $53 'S'
        byte %%3330, %%0333	' .XXXXXX.
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0300	' ......X.
        byte %%3333, %%0033	' XXXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $54 'T'
        byte %%3333, %%0333	' XXXXXXX.
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $55 'U'
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $56 'V'
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0030, %%0030	' .X...X..
        byte %%0030, %%0030	' .X...X..
        byte %%0300, %%0003	' ..X.X...
        byte %%0300, %%0003	' ..X.X...
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $57 'W'
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3003, %%0300	' X..X..X.
        byte %%3003, %%0300	' X..X..X.
        byte %%0303, %%0303	' X.X.X.X.
        byte %%0033, %%0330	' XX...XX.
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $58 'X'
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0030, %%0030	' .X...X..
        byte %%0300, %%0003	' ..X.X...
        byte %%3000, %%0000	' ...X....
        byte %%0300, %%0003	' ..X.X...
        byte %%0030, %%0030	' .X...X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $59 'Y'
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0030, %%0030	' .X...X..
        byte %%0300, %%0003	' ..X.X...
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $5a 'Z'
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0003	' ....X...
        byte %%3000, %%0000	' ...X....
        byte %%0300, %%0000	' ..X.....
        byte %%0030, %%0000	' .X......
        byte %%0003, %%0000	' X.......
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $5b '['
        byte %%3330, %%0033	' .XXXXX..
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0000	' .X......
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $5c '\'
        byte %%0000, %%0000	' ........
        byte %%0003, %%0000	' X.......
        byte %%0033, %%0000	' XX......
        byte %%0330, %%0000	' .XX.....
        byte %%3300, %%0000	' ..XX....
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0033	' ....XX..
        byte %%0000, %%0330	' .....XX.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $5d ']'
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0030	' .....X..
        byte %%0000, %%0030	' .....X..
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $5e '^'
        byte %%3000, %%0000	' ...X....
        byte %%0300, %%0003	' ..X.X...
        byte %%0030, %%0030	' .X...X..
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $5f '_'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $60 '`'
        byte %%0300, %%0000	' ..X.....
        byte %%3300, %%0000	' ..XX....
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0003	' ....X...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $61 'a'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3330, %%0003	' .XXXX...
        byte %%0000, %%0030	' .....X..
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0030	' X....X..
        byte %%0003, %%0030	' X....X..
        byte %%3330, %%0303	' .XXXX.X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $62 'b'
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%3333, %%0003	' XXXXX...
        byte %%0003, %%0030	' X....X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0030	' X....X..
        byte %%3333, %%0003	' XXXXX...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $63 'c'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $64 'd'
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0300	' ......X.
        byte %%3300, %%0333	' ..XXXXX.
        byte %%0030, %%0300	' .X....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0030, %%0300	' .X....X.
        byte %%3300, %%0333	' ..XXXXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $65 'e'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3333, %%0033	' XXXXXX..
        byte %%0003, %%0000	' X.......
        byte %%3330, %%0333	' .XXXXXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $66 'f'
        byte %%3000, %%0033	' ...XXX..
        byte %%0300, %%0300	' ..X...X.
        byte %%0300, %%0000	' ..X.....
        byte %%0300, %%0000	' ..X.....
        byte %%3333, %%0003	' XXXXX...
        byte %%0300, %%0000	' ..X.....
        byte %%0300, %%0000	' ..X.....
        byte %%0300, %%0000	' ..X.....
        byte %%0300, %%0000	' ..X.....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $67 'g'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0333	' .XXXXXX.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0300	' ......X.
        byte %%3333, %%0033	' XXXXXX..
        byte %%0000, %%0000	' ........
' Char $68 'h'
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%3333, %%0033	' XXXXXX..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $69 'i'
        byte %%3300, %%0000	' ..XX....
        byte %%3300, %%0000	' ..XX....
        byte %%0000, %%0000	' ........
        byte %%3300, %%0000	' ..XX....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $6a 'j'
        byte %%3000, %%0003	' ...XX...
        byte %%3000, %%0003	' ...XX...
        byte %%0000, %%0000	' ........
        byte %%3300, %%0033	' ..XXXX..
        byte %%0000, %%0003	' ....X...
        byte %%0000, %%0003	' ....X...
        byte %%0000, %%0003	' ....X...
        byte %%0000, %%0003	' ....X...
        byte %%0000, %%0003	' ....X...
        byte %%0003, %%0003	' X...X...
        byte %%3330, %%0000	' .XXX....
        byte %%0000, %%0000	' ........
' Char $6b 'k'
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0030	' X....X..
        byte %%0003, %%0003	' X...X...
        byte %%3333, %%0000	' XXXX....
        byte %%0003, %%0003	' X...X...
        byte %%0003, %%0030	' X....X..
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $6c 'l'
        byte %%3300, %%0000	' ..XX....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $6d 'm'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0333, %%0033	' XXX.XX..
        byte %%3003, %%0300	' X..X..X.
        byte %%3003, %%0300	' X..X..X.
        byte %%3003, %%0300	' X..X..X.
        byte %%3003, %%0300	' X..X..X.
        byte %%3003, %%0300	' X..X..X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $6e 'n'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3303, %%0003	' X.XXX...
        byte %%0033, %%0030	' XX...X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $6f 'o'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3300, %%0003	' ..XXX...
        byte %%0030, %%0030	' .X...X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0030, %%0030	' .X...X..
        byte %%3300, %%0003	' ..XXX...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $70 'p'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3303, %%0003	' X.XXX...
        byte %%0033, %%0030	' XX...X..
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0033, %%0030	' XX...X..
        byte %%3303, %%0003	' X.XXX...
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0000, %%0000	' ........
' Char $71 'q'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3300, %%0303	' ..XXX.X.
        byte %%0030, %%0330	' .X...XX.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0030, %%0330	' .X...XX.
        byte %%3300, %%0303	' ..XXX.X.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0000	' ........
' Char $72 'r'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3303, %%0033	' X.XXXX..
        byte %%0033, %%0300	' XX....X.
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0003, %%0000	' X.......
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $73 's'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3330, %%0033	' .XXXXX..
        byte %%0003, %%0000	' X.......
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0300	' ......X.
        byte %%0003, %%0300	' X.....X.
        byte %%3330, %%0033	' .XXXXX..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $74 't'
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0000	' .X......
        byte %%3333, %%0000	' XXXX....
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0000	' .X......
        byte %%0030, %%0030	' .X...X..
        byte %%3300, %%0003	' ..XXX...
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $75 'u'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0033, %%0330	' XX...XX.
        byte %%3300, %%0303	' ..XXX.X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $76 'v'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0030, %%0030	' .X...X..
        byte %%0030, %%0030	' .X...X..
        byte %%0300, %%0003	' ..X.X...
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $77 'w'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%3003, %%0300	' X..X..X.
        byte %%0303, %%0303	' X.X.X.X.
        byte %%0033, %%0330	' XX...XX.
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $78 'x'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0003, %%0300	' X.....X.
        byte %%0030, %%0030	' .X...X..
        byte %%3300, %%0003	' ..XXX...
        byte %%3300, %%0003	' ..XXX...
        byte %%0030, %%0030	' .X...X..
        byte %%0003, %%0300	' X.....X.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $79 'y'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0300	' X.....X.
        byte %%0003, %%0330	' X....XX.
        byte %%3330, %%0303	' .XXXX.X.
        byte %%0000, %%0300	' ......X.
        byte %%0000, %%0030	' .....X..
        byte %%3333, %%0003	' XXXXX...
        byte %%0000, %%0000	' ........
' Char $7a 'z'
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0030	' .....X..
        byte %%3000, %%0003	' ...XX...
        byte %%3300, %%0000	' ..XX....
        byte %%0030, %%0000	' .X......
        byte %%3333, %%0333	' XXXXXXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $7b '{'
        byte %%0000, %%0333	' ....XXX.
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0330, %%0000	' .XX.....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0333	' ....XXX.
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $7c '|'
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $7d '}'
        byte %%0333, %%0000	' XXX.....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0000, %%0033	' ....XX..
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%3000, %%0000	' ...X....
        byte %%0333, %%0000	' XXX.....
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $7e '~'
        byte %%0000, %%0000	' ........
        byte %%0330, %%0300	' .xx...x.
        byte %%3003, %%0300	' x..x..x.
        byte %%0003, %%0033	' x...xx..
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
        byte %%0000, %%0000	' ........
' Char $7f ''
        byte %%0303, %%0303	' X.X.X.X.
        byte %%3030, %%3030	' .X.X.X.X
        byte %%0303, %%0303	' X.X.X.X.
        byte %%3030, %%3030	' .X.X.X.X
        byte %%0303, %%0303	' X.X.X.X.
        byte %%3030, %%3030	' .X.X.X.X
        byte %%0303, %%0303	' X.X.X.X.
        byte %%3030, %%3030	' .X.X.X.X
        byte %%0303, %%0303	' X.X.X.X.
        byte %%3030, %%3030	' .X.X.X.X
        byte %%0303, %%0303	' X.X.X.X.
        byte %%3030, %%3030	' .X.X.X.X


